#!/usr/local/bin/perl

use strict;
use warnings;

use DateTime;
use XML::Atom::Client;
use HTML::Template;
use Net::MovableType;

#----------------------------------------------------------------------
# settings
#----------------------------------------------------------------------
my $tmpl_filename = "/home/cheebow/bin/hbm/hbm.tmpl";

my $feedURI = 'http://b.hatena.ne.jp/atom/feed';
my $hatena_username = 'username';
my $hatena_password = 'password';

my $xmlrpcURL = 'http://<MT>/mt-xmlrpc.cgi';
my $xmlrpc_username = 'username';
my $xmlrpc_password = 'xml_rpc_password';
my $xmlrpc_blog_id = 1;
my $xmlrpc_category = "Bookmark";


#----------------------------------------------------------------------
# utils
#----------------------------------------------------------------------
sub iso2DateTime {
	my $ts = shift;
	return unless $ts =~ /^(\d{4})(?:-?(\d{2})(?:-?(\d\d?)(?:T(\d{2}):(\d{2}):(\d{2})(?:\.\d+)?(?:Z|([+-]\d{2}:\d{2}))?)?)?)?/;
	my ($y, $mo, $d, $h, $m, $s, $zone) =
		($1, $2 || 1, $3 || 1, $4 || 0, $5 || 0, $6 || 0, $7);

	my $dt = DateTime->new(
				year   => $y,
				month  => $mo,
				day    => $d,
				hour   => $h,
				minute => $m,
				second => $s,
				nanosecond => 0,
				time_zone => $zone,
				);
	return $dt;
}

#----------------------------------------------------------------------
# feed
#----------------------------------------------------------------------
my $api = XML::Atom::Client->new;
$api->username($hatena_username);
$api->password($hatena_password);

my $feed = $api->getFeed($feedURI);

die "getFeed Error" unless $feed;

my @entries = $feed->entries;
my @yesterdayEntries;
my $dt_yesterday;

for my $entry (@entries) {
	my $issued = $entry->issued;
	my $dt = iso2DateTime($issued);
	my $issuedDate = $dt->ymd('');
	$dt_yesterday = DateTime->now->add( days => -1);
	$dt_yesterday->set_time_zone( '+09:00' );
	my $yesterdayDate = $dt_yesterday ->ymd('');
	if ($issuedDate eq $yesterdayDate) {
		push @yesterdayEntries, $entry;
	}
}

#----------------------------------------------------------------------
# Template
#----------------------------------------------------------------------
my $tmpl = HTML::Template->new(
	filename => $tmpl_filename,
);

my @tmpl_entries;
for my $entry (@yesterdayEntries) {
	my @tmpl_entry = (
		{
			title => $entry->title,
			url => $entry->link->href,
			summary => $entry->summary,
		}
	);

	push @tmpl_entries, @tmpl_entry; 
}

die if ((scalar @tmpl_entries) == 0);

$tmpl->param(entry => \@tmpl_entries);

my $text = $tmpl->output();

print $text;

#----------------------------------------------------------------------
# MovableType
#----------------------------------------------------------------------
my $mt = new Net::MovableType($xmlrpcURL);
$mt->username($xmlrpc_username);
$mt->password($xmlrpc_password);
$mt->blogId($xmlrpc_blog_id );

my $title       = $feed->title . "(" . $dt_yesterday ->ymd('-') . ")";
my $description = $text;

my $entry = {
    title       => $title,
    description => $description
};

my $new_id = $mt->newPost($entry, 0);
$mt->setPostCategories($new_id, $xmlrpc_category);
$mt->publishPost($new_id);
